# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ExecutionStateEnum


class Rollback(BaseModel):
    device_rollback: Optional["RollbackDeviceRollback"] = Field(alias="deviceRollback")


class RollbackDeviceRollback(BaseModel):
    execution: Optional["RollbackDeviceRollbackExecution"]


class RollbackDeviceRollbackExecution(BaseModel):
    id: str
    task_id: Optional[str] = Field(alias="taskId")
    state: Optional[ExecutionStateEnum]


Rollback.model_rebuild()
RollbackDeviceRollback.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    DeviceExecutionStateEnum,
    ExecutionResultStateEnum,
    ExecutionStateEnum,
    ExecutionTypeEnum,
    ProviderTypeEnum,
    RunOnEnum,
)


class ProcessOverview(BaseModel):
    process_executions: Optional["ProcessOverviewProcessExecutions"] = Field(
        alias="processExecutions"
    )


class ProcessOverviewProcessExecutions(BaseModel):
    results: Optional[List[Optional["ProcessOverviewProcessExecutionsResults"]]]


class ProcessOverviewProcessExecutionsResults(BaseModel):
    id: str
    name: Optional[str]
    executions: Optional[
        List[Optional["ProcessOverviewProcessExecutionsResultsExecutions"]]
    ]


class ProcessOverviewProcessExecutionsResultsExecutions(BaseModel):
    id: str
    name: Optional[str]
    state: Optional[ExecutionStateEnum]
    execution_type: Optional[ExecutionTypeEnum] = Field(alias="executionType")
    task: Optional[str]
    created_at: Optional[Any] = Field(alias="createdAt")
    updated_at: Optional[Any] = Field(alias="updatedAt")
    args: Optional[Any]
    do: Optional[str]
    done: Optional[str]
    log: Optional[str]
    execution_results: Optional[
        List[
            Optional[
                "ProcessOverviewProcessExecutionsResultsExecutionsExecutionResults"
            ]
        ]
    ] = Field(alias="executionResults")
    neops_task: Optional[
        "ProcessOverviewProcessExecutionsResultsExecutionsNeopsTask"
    ] = Field(alias="neopsTask")
    device_execution: Optional[
        List[
            Optional["ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecution"]
        ]
    ] = Field(alias="deviceExecution")


class ProcessOverviewProcessExecutionsResultsExecutionsExecutionResults(BaseModel):
    id: str
    state: Optional[ExecutionResultStateEnum]
    message: Optional[str]


class ProcessOverviewProcessExecutionsResultsExecutionsNeopsTask(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    provider: Optional[
        "ProcessOverviewProcessExecutionsResultsExecutionsNeopsTaskProvider"
    ]


class ProcessOverviewProcessExecutionsResultsExecutionsNeopsTaskProvider(BaseModel):
    provider_type: Optional[ProviderTypeEnum] = Field(alias="providerType")


class ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecution(BaseModel):
    id: str
    state: Optional[DeviceExecutionStateEnum]
    created_at: Optional[Any] = Field(alias="createdAt")
    updated_at: Optional[Any] = Field(alias="updatedAt")
    changed: Optional[bool]
    will_change: Optional[bool] = Field(alias="willChange")
    run_on: Optional[RunOnEnum] = Field(alias="runOn")
    execute_on: Optional[List[Optional[int]]] = Field(alias="executeOn")
    device: Optional[
        "ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevice"
    ]


class ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevice(BaseModel):
    id: str
    ip: Optional[str]
    hostname: Optional[str]
    vendor: Optional[str]
    model: Optional[str]
    platform: Optional[
        "ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevicePlatform"
    ]
    software_release: Optional[str] = Field(alias="softwareRelease")


class ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevicePlatform(
    BaseModel
):
    id: str
    name: Optional[str]


ProcessOverview.model_rebuild()
ProcessOverviewProcessExecutions.model_rebuild()
ProcessOverviewProcessExecutionsResults.model_rebuild()
ProcessOverviewProcessExecutionsResultsExecutions.model_rebuild()
ProcessOverviewProcessExecutionsResultsExecutionsNeopsTask.model_rebuild()
ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecution.model_rebuild()
ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevice.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class DeviceUpsert(BaseModel):
    device_upsert: Optional["DeviceUpsertDeviceUpsert"] = Field(alias="deviceUpsert")


class DeviceUpsertDeviceUpsert(BaseModel):
    device: Optional["DeviceUpsertDeviceUpsertDevice"]


class DeviceUpsertDeviceUpsertDevice(BaseModel):
    id: str
    hostname: Optional[str]
    connection_options: Optional[Any] = Field(alias="connectionOptions")
    ip: Optional[str]
    groups: Optional[List[Optional["DeviceUpsertDeviceUpsertDeviceGroups"]]]
    platform: Optional["DeviceUpsertDeviceUpsertDevicePlatform"]
    username: Optional[str]


class DeviceUpsertDeviceUpsertDeviceGroups(BaseModel):
    id: str
    name: Optional[str]


class DeviceUpsertDeviceUpsertDevicePlatform(BaseModel):
    id: str
    name: Optional[str]


DeviceUpsert.model_rebuild()
DeviceUpsertDeviceUpsert.model_rebuild()
DeviceUpsertDeviceUpsertDevice.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class LocationUpsert(BaseModel):
    location_upsert: Optional["LocationUpsertLocationUpsert"] = Field(
        alias="locationUpsert"
    )


class LocationUpsertLocationUpsert(BaseModel):
    location: Optional["LocationUpsertLocationUpsertLocation"]


class LocationUpsertLocationUpsertLocation(BaseModel):
    id: str
    name: Optional[str]
    title: Optional[str]
    description: Optional[str]
    address: Optional[str]
    zip_code: Optional[str] = Field(alias="zipCode")
    city: Optional[str]
    country: Optional[str]
    devices: Optional[List[Optional["LocationUpsertLocationUpsertLocationDevices"]]]
    lon: Optional[float]
    lat: Optional[float]


class LocationUpsertLocationUpsertLocationDevices(BaseModel):
    id: str
    hostname: Optional[str]
    ip: Optional[str]


LocationUpsert.model_rebuild()
LocationUpsertLocationUpsert.model_rebuild()
LocationUpsertLocationUpsertLocation.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RoleDeviceGroupUpsert(BaseModel):
    role_device_group_upsert: Optional["RoleDeviceGroupUpsertRoleDeviceGroupUpsert"] = (
        Field(alias="roleDeviceGroupUpsert")
    )


class RoleDeviceGroupUpsertRoleDeviceGroupUpsert(BaseModel):
    role_device_group: Optional[
        "RoleDeviceGroupUpsertRoleDeviceGroupUpsertRoleDeviceGroup"
    ] = Field(alias="roleDeviceGroup")


class RoleDeviceGroupUpsertRoleDeviceGroupUpsertRoleDeviceGroup(BaseModel):
    id: str
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")


RoleDeviceGroupUpsert.model_rebuild()
RoleDeviceGroupUpsertRoleDeviceGroupUpsert.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ExecutionStateEnum


class SingleDiscovery(BaseModel):
    discovery: Optional["SingleDiscoveryDiscovery"]


class SingleDiscoveryDiscovery(BaseModel):
    execution: Optional["SingleDiscoveryDiscoveryExecution"]


class SingleDiscoveryDiscoveryExecution(BaseModel):
    id: str
    task_id: Optional[str] = Field(alias="taskId")
    state: Optional[ExecutionStateEnum]


SingleDiscovery.model_rebuild()
SingleDiscoveryDiscovery.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    DeviceExecutionStateEnum,
    ExecutionStateEnum,
    ExecutionTypeEnum,
    ProviderTypeEnum,
    RunOnEnum,
)


class ExecuteNeopsTask(BaseModel):
    execute_neops_task: Optional["ExecuteNeopsTaskExecuteNeopsTask"] = Field(
        alias="executeNeopsTask"
    )


class ExecuteNeopsTaskExecuteNeopsTask(BaseModel):
    executions: Optional[List[Optional["ExecuteNeopsTaskExecuteNeopsTaskExecutions"]]]


class ExecuteNeopsTaskExecuteNeopsTaskExecutions(BaseModel):
    args: Optional[Any]
    id: str
    task_id: Optional[str] = Field(alias="taskId")
    name: Optional[str]
    created_at: Optional[Any] = Field(alias="createdAt")
    updated_at: Optional[Any] = Field(alias="updatedAt")
    state: Optional[ExecutionStateEnum]
    execution_type: Optional[ExecutionTypeEnum] = Field(alias="executionType")
    task_id: Optional[str] = Field(alias="taskId")
    task: Optional[str]
    neops_task: Optional["ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTask"] = Field(
        alias="neopsTask"
    )
    device_execution: Optional[
        List[Optional["ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecution"]]
    ] = Field(alias="deviceExecution")


class ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTask(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    provider: Optional["ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTaskProvider"]


class ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTaskProvider(BaseModel):
    provider_type: Optional[ProviderTypeEnum] = Field(alias="providerType")


class ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecution(BaseModel):
    execution: Optional[
        "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionExecution"
    ]
    id: str
    device: Optional["ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevice"]
    run_on: Optional[RunOnEnum] = Field(alias="runOn")
    execute_on: Optional[List[Optional[int]]] = Field(alias="executeOn")
    state: Optional[DeviceExecutionStateEnum]
    exception: Optional[str]
    do: Optional[str]
    done: Optional[str]
    changed: Optional[bool]
    will_change: Optional[bool] = Field(alias="willChange")
    log: Optional[str]


class ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionExecution(BaseModel):
    id: str


class ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevice(BaseModel):
    id: str
    hostname: Optional[str]
    vendor: Optional[str]
    model: Optional[str]
    platform: Optional[
        "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevicePlatform"
    ]
    software_release: Optional[str] = Field(alias="softwareRelease")


class ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevicePlatform(
    BaseModel
):
    id: str
    name: Optional[str]


ExecuteNeopsTask.model_rebuild()
ExecuteNeopsTaskExecuteNeopsTask.model_rebuild()
ExecuteNeopsTaskExecuteNeopsTaskExecutions.model_rebuild()
ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTask.model_rebuild()
ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecution.model_rebuild()
ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevice.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class AddApiKey(BaseModel):
    static_api_key_create: Optional["AddApiKeyStaticApiKeyCreate"] = Field(
        alias="staticApiKeyCreate"
    )


class AddApiKeyStaticApiKeyCreate(BaseModel):
    app: Optional[str]
    access_token: Optional[str] = Field(alias="accessToken")


AddApiKey.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ExecutionStateEnum


class Discovery(BaseModel):
    execute: Optional["DiscoveryExecute"]


class DiscoveryExecute(BaseModel):
    execution: Optional["DiscoveryExecuteExecution"]


class DiscoveryExecuteExecution(BaseModel):
    id: str
    task_id: Optional[str] = Field(alias="taskId")
    state: Optional[ExecutionStateEnum]


Discovery.model_rebuild()
DiscoveryExecute.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RoleDeviceGroup(BaseModel):
    role_device_group: Optional["RoleDeviceGroupRoleDeviceGroup"] = Field(
        alias="roleDeviceGroup"
    )


class RoleDeviceGroupRoleDeviceGroup(BaseModel):
    results: Optional[List[Optional["RoleDeviceGroupRoleDeviceGroupResults"]]]


class RoleDeviceGroupRoleDeviceGroupResults(BaseModel):
    id: str
    role: Optional["RoleDeviceGroupRoleDeviceGroupResultsRole"]
    device_group: Optional["RoleDeviceGroupRoleDeviceGroupResultsDeviceGroup"] = Field(
        alias="deviceGroup"
    )
    permission: Optional[int]


class RoleDeviceGroupRoleDeviceGroupResultsRole(BaseModel):
    id: str
    name: Optional[str]


class RoleDeviceGroupRoleDeviceGroupResultsDeviceGroup(BaseModel):
    id: str
    name: Optional[str]


RoleDeviceGroup.model_rebuild()
RoleDeviceGroupRoleDeviceGroup.model_rebuild()
RoleDeviceGroupRoleDeviceGroupResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ConnectionStateEnum


class Devices(BaseModel):
    devices_elastic: Optional["DevicesDevicesElastic"] = Field(alias="devicesElastic")


class DevicesDevicesElastic(BaseModel):
    total_count: Optional[int] = Field(alias="totalCount")
    results: Optional[List[Optional["DevicesDevicesElasticResults"]]]


class DevicesDevicesElasticResults(BaseModel):
    id: str
    created_at: Optional[Any] = Field(alias="createdAt")
    updated_at: Optional[Any] = Field(alias="updatedAt")
    hostname: Optional[str]
    ip: Optional[str]
    connection_state: Optional[ConnectionStateEnum] = Field(alias="connectionState")
    facts: Optional[Any]
    software_release: Optional[str] = Field(alias="softwareRelease")
    platform: Optional["DevicesDevicesElasticResultsPlatform"]
    vendor: Optional[str]
    model: Optional[str]
    serial: Optional[str]
    username: Optional[str]
    current_configuration: Optional[str] = Field(alias="currentConfiguration")
    groups: Optional[List[Optional["DevicesDevicesElasticResultsGroups"]]]
    checks: Optional[Any]
    group_count: Optional[int] = Field(alias="groupCount")
    interface_count: Optional[int] = Field(alias="interfaceCount")


class DevicesDevicesElasticResultsPlatform(BaseModel):
    id: str
    name: Optional[str]
    short_name: Optional[str] = Field(alias="shortName")


class DevicesDevicesElasticResultsGroups(BaseModel):
    id: str
    name: Optional[str]


Devices.model_rebuild()
DevicesDevicesElastic.model_rebuild()
DevicesDevicesElasticResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class DeviceGroupUpsert(BaseModel):
    device_group_upsert: Optional["DeviceGroupUpsertDeviceGroupUpsert"] = Field(
        alias="deviceGroupUpsert"
    )


class DeviceGroupUpsertDeviceGroupUpsert(BaseModel):
    device_group: Optional["DeviceGroupUpsertDeviceGroupUpsertDeviceGroup"] = Field(
        alias="deviceGroup"
    )


class DeviceGroupUpsertDeviceGroupUpsertDeviceGroup(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    title: Optional[str]
    devices: Optional[
        List[Optional["DeviceGroupUpsertDeviceGroupUpsertDeviceGroupDevices"]]
    ]


class DeviceGroupUpsertDeviceGroupUpsertDeviceGroupDevices(BaseModel):
    id: str
    hostname: Optional[str]
    ip: Optional[str]


DeviceGroupUpsert.model_rebuild()
DeviceGroupUpsertDeviceGroupUpsert.model_rebuild()
DeviceGroupUpsertDeviceGroupUpsertDeviceGroup.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class AddUsersToRole(BaseModel):
    role_add_users: Optional["AddUsersToRoleRoleAddUsers"] = Field(alias="roleAddUsers")


class AddUsersToRoleRoleAddUsers(BaseModel):
    role: Optional["AddUsersToRoleRoleAddUsersRole"]


class AddUsersToRoleRoleAddUsersRole(BaseModel):
    id: str
    name: Optional[str]
    users: Optional[List[Optional["AddUsersToRoleRoleAddUsersRoleUsers"]]]


class AddUsersToRoleRoleAddUsersRoleUsers(BaseModel):
    id: str
    username: Optional[str]


AddUsersToRole.model_rebuild()
AddUsersToRoleRoleAddUsers.model_rebuild()
AddUsersToRoleRoleAddUsersRole.model_rebuild()



# Generated by ariadne-codegen

from .abort_execution import (
    AbortExecution,
    AbortExecutionAbortExecution,
    AbortExecutionAbortExecutionExecutions,
    AbortExecutionAbortExecutionExecutionsNeopsTask,
)
from .add_api_key import AddApiKey, AddApiKeyStaticApiKeyCreate
from .add_role import (
    AddRole,
    AddRoleRoleUpsert,
    AddRoleRoleUpsertRole,
    AddRoleRoleUpsertRoleUsers,
)
from .add_role_device_group import (
    AddRoleDeviceGroup,
    AddRoleDeviceGroupRoleDeviceGroupUpsert,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroup,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupDeviceGroup,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupDeviceGroupDevices,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupRole,
    AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupRoleUsers,
)
from .add_role_neops_task import (
    AddRoleNeopsTask,
    AddRoleNeopsTaskRoleNeopsTaskUpsert,
    AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTask,
    AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskNeopsTask,
    AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskRole,
    AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskRoleUsers,
)
from .add_user import AddUser, AddUserLocalUserCreate, AddUserLocalUserCreateLocalUser
from .add_users_to_role import (
    AddUsersToRole,
    AddUsersToRoleRoleAddUsers,
    AddUsersToRoleRoleAddUsersRole,
    AddUsersToRoleRoleAddUsersRoleUsers,
)
from .archive_or_delete_task import (
    ArchiveOrDeleteTask,
    ArchiveOrDeleteTaskNeopsTaskDelete,
    ArchiveOrDeleteTaskNeopsTaskDeleteNeopsTask,
)
from .async_base_client import AsyncBaseClient
from .autocomplete_fields import AutocompleteFields
from .base_model import BaseModel, Upload
from .client import Client
from .client_aggregation import (
    ClientAggregation,
    ClientAggregationClientAggregation,
    ClientAggregationClientAggregationResults,
)
from .clients import (
    Clients,
    ClientsClientsElastic,
    ClientsClientsElasticResults,
    ClientsClientsElasticResultsInterface,
    ClientsClientsElasticResultsInterfaceDevice,
    ClientsClientsElasticResultsLocation,
)
from .cron_execution_type import (
    CronExecutionType,
    CronExecutionTypeCronjobExecutionTypes,
    CronExecutionTypeCronjobExecutionTypesResults,
)
from .device_aggregation import (
    DeviceAggregation,
    DeviceAggregationDeviceAggregation,
    DeviceAggregationDeviceAggregationResults,
)
from .device_group_elastic import (
    DeviceGroupElastic,
    DeviceGroupElasticGroupsElastic,
    DeviceGroupElasticGroupsElasticResults,
    DeviceGroupElasticGroupsElasticResultsLocation,
)
from .device_group_upsert import (
    DeviceGroupUpsert,
    DeviceGroupUpsertDeviceGroupUpsert,
    DeviceGroupUpsertDeviceGroupUpsertDeviceGroup,
    DeviceGroupUpsertDeviceGroupUpsertDeviceGroupDevices,
)
from .device_upsert import (
    DeviceUpsert,
    DeviceUpsertDeviceUpsert,
    DeviceUpsertDeviceUpsertDevice,
    DeviceUpsertDeviceUpsertDeviceGroups,
    DeviceUpsertDeviceUpsertDevicePlatform,
)
from .devices import (
    Devices,
    DevicesDevicesElastic,
    DevicesDevicesElasticResults,
    DevicesDevicesElasticResultsGroups,
    DevicesDevicesElasticResultsPlatform,
)
from .discovery import Discovery, DiscoveryExecute, DiscoveryExecuteExecution
from .enums import (
    AggregationsType,
    ChartType,
    CheckResultEnum,
    ConnectionStateEnum,
    CronExecuteTypeEnum,
    CronJobExecuteTypeEnum,
    DeviceExecutionStateEnum,
    EntityType,
    ExecutionResultStateEnum,
    ExecutionStateEnum,
    ExecutionTypeEnum,
    IndexesEnum,
    InterfaceStateEnum,
    NeopsTask_ProviderTypeEnum,
    NeopsTask_RunOnEnum,
    NeopsTask_RunOnStrictEnum,
    NeopsTask_ValidityStateEnum,
    NeopsTaskCronJobExecuteTypeEnum,
    OutputSchemaTypeEnum,
    ProviderSchemaEnum,
    ProviderTypeEnum,
    RegexTypeEnum,
    RunOnEnum,
)
from .exceptions import (
    GraphQLClientError,
    GraphQLClientGraphQLError,
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQLClientInvalidResponseError,
)
from .execute_neops_task import (
    ExecuteNeopsTask,
    ExecuteNeopsTaskExecuteNeopsTask,
    ExecuteNeopsTaskExecuteNeopsTaskExecutions,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecution,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevice,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevicePlatform,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionExecution,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTask,
    ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTaskProvider,
)
from .execution import (
    Execution,
    ExecutionExecutions,
    ExecutionExecutionsResults,
    ExecutionExecutionsResultsDeviceExecution,
    ExecutionExecutionsResultsDeviceExecutionDevice,
    ExecutionExecutionsResultsDeviceExecutionDevicePlatform,
    ExecutionExecutionsResultsExecutionResults,
    ExecutionExecutionsResultsExecutionResultsClientexecutionresult,
    ExecutionExecutionsResultsExecutionResultsClientexecutionresultClient,
    ExecutionExecutionsResultsExecutionResultsDeviceexecutionresult,
    ExecutionExecutionsResultsExecutionResultsDeviceexecutionresultDevice,
    ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresult,
    ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup,
    ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresult,
    ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresultInterface,
    ExecutionExecutionsResultsNeopsTask,
    ExecutionExecutionsResultsNeopsTaskProvider,
    ExecutionExecutionsResultsProcess,
)
from .execution_subscription import (
    ExecutionSubscription,
    ExecutionSubscriptionExecutionSubscription,
    ExecutionSubscriptionExecutionSubscriptionExecution,
    ExecutionSubscriptionExecutionSubscriptionExecutionNeopsTask,
    ExecutionSubscriptionExecutionSubscriptionExecutionNeopsTaskProvider,
    ExecutionSubscriptionExecutionSubscriptionExecutionProcess,
)
from .executions_detail import (
    ExecutionsDetail,
    ExecutionsDetailExecutions,
    ExecutionsDetailExecutionsResults,
    ExecutionsDetailExecutionsResultsExecutionResults,
    ExecutionsDetailExecutionsResultsExecutionResultsClientexecutionresult,
    ExecutionsDetailExecutionsResultsExecutionResultsClientexecutionresultClient,
    ExecutionsDetailExecutionsResultsExecutionResultsDeviceexecutionresult,
    ExecutionsDetailExecutionsResultsExecutionResultsDeviceexecutionresultDevice,
    ExecutionsDetailExecutionsResultsExecutionResultsDevicegroupexecutionresult,
    ExecutionsDetailExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup,
    ExecutionsDetailExecutionsResultsExecutionResultsInterfaceexecutionresult,
    ExecutionsDetailExecutionsResultsExecutionResultsInterfaceexecutionresultInterface,
    ExecutionsDetailExecutionsResultsNeopsTask,
    ExecutionsDetailExecutionsResultsNeopsTaskProvider,
    ExecutionsDetailExecutionsResultsProcess,
    ExecutionsDetailExecutionsResultsUser,
)
from .executions_elastic import (
    ExecutionsElastic,
    ExecutionsElasticExecutionsElastic,
    ExecutionsElasticExecutionsElasticResults,
    ExecutionsElasticExecutionsElasticResultsNeopsTask,
    ExecutionsElasticExecutionsElasticResultsNeopsTaskProvider,
    ExecutionsElasticExecutionsElasticResultsProcess,
    ExecutionsElasticExecutionsElasticResultsUser,
)
from .executions_simple import (
    ExecutionsSimple,
    ExecutionsSimpleExecutions,
    ExecutionsSimpleExecutionsResults,
    ExecutionsSimpleExecutionsResultsNeopsTask,
    ExecutionsSimpleExecutionsResultsNeopsTaskProvider,
    ExecutionsSimpleExecutionsResultsProcess,
    ExecutionsSimpleExecutionsResultsUser,
)
from .get_role import GetRole, GetRoleRole, GetRoleRoleResults
from .group_aggregation import (
    GroupAggregation,
    GroupAggregationGroupAggregation,
    GroupAggregationGroupAggregationResults,
)
from .interface_aggregation import (
    InterfaceAggregation,
    InterfaceAggregationInterfaceAggregation,
    InterfaceAggregationInterfaceAggregationResults,
)
from .interfaces import (
    Interfaces,
    InterfacesInterfacesElastic,
    InterfacesInterfacesElasticResults,
    InterfacesInterfacesElasticResultsDevice,
    InterfacesInterfacesElasticResultsInterface,
)
from .json_form import (
    JsonForm,
    JsonFormJsonForm,
    JsonFormJsonFormClients,
    JsonFormJsonFormDevices,
    JsonFormJsonFormGroups,
    JsonFormJsonFormInterfaces,
    JsonFormJsonFormInterfacesDevice,
)
from .location_upsert import (
    LocationUpsert,
    LocationUpsertLocationUpsert,
    LocationUpsertLocationUpsertLocation,
    LocationUpsertLocationUpsertLocationDevices,
)
from .login import Login, LoginLogin, LoginLoginUser
from .neops_provider import (
    NeopsProvider,
    NeopsProviderNeopsTaskProvider,
    NeopsProviderNeopsTaskProviderResults,
)
from .neops_task_create_mutation import (
    NeopsTaskCreateMutation,
    NeopsTaskCreateMutationNeopsTaskUpsert,
    NeopsTaskCreateMutationNeopsTaskUpsertNeopsTask,
)
from .neops_task_unarchive import (
    NeopsTaskUnarchive,
    NeopsTaskUnarchiveNeopsTaskUpsert,
    NeopsTaskUnarchiveNeopsTaskUpsertNeopsTask,
)
from .neops_tasks import (
    NeopsTasks,
    NeopsTasksNeopsTasks,
    NeopsTasksNeopsTasksResults,
    NeopsTasksNeopsTasksResultsPostRunTasks,
    NeopsTasksNeopsTasksResultsPreRunTasks,
    NeopsTasksNeopsTasksResultsProvider,
)
from .permissions import (
    Permissions,
    PermissionsPermissions,
    PermissionsPermissionsResults,
)
from .platforms import Platforms, PlatformsPlatforms, PlatformsPlatformsResults
from .process_overview import (
    ProcessOverview,
    ProcessOverviewProcessExecutions,
    ProcessOverviewProcessExecutionsResults,
    ProcessOverviewProcessExecutionsResultsExecutions,
    ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecution,
    ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevice,
    ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevicePlatform,
    ProcessOverviewProcessExecutionsResultsExecutionsExecutionResults,
    ProcessOverviewProcessExecutionsResultsExecutionsNeopsTask,
    ProcessOverviewProcessExecutionsResultsExecutionsNeopsTaskProvider,
)
from .providers import (
    Providers,
    ProvidersNeopsTaskProvider,
    ProvidersNeopsTaskProviderResults,
)
from .refresh_token import RefreshToken, RefreshTokenRefreshToken
from .reports import (
    Reports,
    ReportsReports,
    ReportsReportsResults,
    ReportsReportsResultsScope,
)
from .reports_execute import (
    ReportsExecute,
    ReportsExecuteReportsExecute,
    ReportsExecuteReportsExecuteReportExecution,
)
from .role_device_group import (
    RoleDeviceGroup,
    RoleDeviceGroupRoleDeviceGroup,
    RoleDeviceGroupRoleDeviceGroupResults,
    RoleDeviceGroupRoleDeviceGroupResultsDeviceGroup,
    RoleDeviceGroupRoleDeviceGroupResultsRole,
)
from .role_device_group_upsert import (
    RoleDeviceGroupUpsert,
    RoleDeviceGroupUpsertRoleDeviceGroupUpsert,
    RoleDeviceGroupUpsertRoleDeviceGroupUpsertRoleDeviceGroup,
)
from .role_neops_task import (
    RoleNeopsTask,
    RoleNeopsTaskRoleNeopsTask,
    RoleNeopsTaskRoleNeopsTaskResults,
    RoleNeopsTaskRoleNeopsTaskResultsNeopsTask,
    RoleNeopsTaskRoleNeopsTaskResultsRole,
)
from .role_neops_task_upsert import (
    RoleNeopsTaskUpsert,
    RoleNeopsTaskUpsertRoleNeopsTaskUpsert,
    RoleNeopsTaskUpsertRoleNeopsTaskUpsertRoleNeopsTask,
)
from .role_permission_element import (
    RolePermissionElement,
    RolePermissionElementRolePermissionElement,
    RolePermissionElementRolePermissionElementResults,
    RolePermissionElementRolePermissionElementResultsPermissionElement,
)
from .role_permission_element_upsert import (
    RolePermissionElementUpsert,
    RolePermissionElementUpsertRolePermissionElementUpsert,
    RolePermissionElementUpsertRolePermissionElementUpsertRolePermissionElement,
)
from .role_permission_upsert import (
    RolePermissionUpsert,
    RolePermissionUpsertRolePermissionUpsert,
    RolePermissionUpsertRolePermissionUpsertRolePermission,
)
from .role_permissions import (
    RolePermissions,
    RolePermissionsRolePermission,
    RolePermissionsRolePermissionResults,
    RolePermissionsRolePermissionResultsDeviceGroupPermissionsAll,
    RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllDeviceGroup,
    RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllRole,
    RolePermissionsRolePermissionResultsNeopsTaskPermissionsAll,
    RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllNeopsTask,
    RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllRole,
    RolePermissionsRolePermissionResultsPermissionElementPermissionsAll,
    RolePermissionsRolePermissionResultsPermissionElementPermissionsAllPermissionElement,
    RolePermissionsRolePermissionResultsPermissionElementPermissionsAllRole,
    RolePermissionsRolePermissionResultsScopePermissionsAll,
    RolePermissionsRolePermissionResultsScopePermissionsAllRole,
    RolePermissionsRolePermissionResultsScopePermissionsAllScope,
    RolePermissionsRolePermissionResultsUsers,
)
from .role_scope_upsert import (
    RoleScopeUpsert,
    RoleScopeUpsertRoleScopeUpsert,
    RoleScopeUpsertRoleScopeUpsertRoleScope,
)
from .role_user import RoleUser, RoleUserRole, RoleUserRoleResults
from .rollback import Rollback, RollbackDeviceRollback, RollbackDeviceRollbackExecution
from .saved_search_create import (
    SavedSearchCreate,
    SavedSearchCreateSavedSearchCreate,
    SavedSearchCreateSavedSearchCreateSavedSearch,
)
from .saved_search_delete import (
    SavedSearchDelete,
    SavedSearchDeleteSavedSearchDelete,
    SavedSearchDeleteSavedSearchDeleteSavedSearch,
)
from .saved_searches import (
    SavedSearches,
    SavedSearchesSavedSearches,
    SavedSearchesSavedSearchesResults,
)
from .scope_delete import (
    ScopeDelete,
    ScopeDeleteScopeDelete,
    ScopeDeleteScopeDeleteScope,
)
from .scopes import Scopes, ScopesScopes, ScopesScopesResults, ScopesScopesResultsTasks
from .scopes_upsert import (
    ScopesUpsert,
    ScopesUpsertScopesUpsert,
    ScopesUpsertScopesUpsertScope,
)
from .single_discovery import (
    SingleDiscovery,
    SingleDiscoveryDiscovery,
    SingleDiscoveryDiscoveryExecution,
)
from .topology import (
    Topology,
    TopologyTopology,
    TopologyTopologyLinks,
    TopologyTopologyLinksProperties,
    TopologyTopologyLinksPropertiesSourceInterface,
    TopologyTopologyLinksPropertiesTargetInterface,
    TopologyTopologyNodes,
    TopologyTopologyNodesProperties,
    TopologyTopologyNodesPropertiesDevice,
)

__all__ = [
    "AbortExecution",
    "AbortExecutionAbortExecution",
    "AbortExecutionAbortExecutionExecutions",
    "AbortExecutionAbortExecutionExecutionsNeopsTask",
    "AddApiKey",
    "AddApiKeyStaticApiKeyCreate",
    "AddRole",
    "AddRoleDeviceGroup",
    "AddRoleDeviceGroupRoleDeviceGroupUpsert",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroup",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupDeviceGroup",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupDeviceGroupDevices",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupRole",
    "AddRoleDeviceGroupRoleDeviceGroupUpsertRoleDeviceGroupRoleUsers",
    "AddRoleNeopsTask",
    "AddRoleNeopsTaskRoleNeopsTaskUpsert",
    "AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTask",
    "AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskNeopsTask",
    "AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskRole",
    "AddRoleNeopsTaskRoleNeopsTaskUpsertRoleNeopsTaskRoleUsers",
    "AddRoleRoleUpsert",
    "AddRoleRoleUpsertRole",
    "AddRoleRoleUpsertRoleUsers",
    "AddUser",
    "AddUserLocalUserCreate",
    "AddUserLocalUserCreateLocalUser",
    "AddUsersToRole",
    "AddUsersToRoleRoleAddUsers",
    "AddUsersToRoleRoleAddUsersRole",
    "AddUsersToRoleRoleAddUsersRoleUsers",
    "AggregationsType",
    "ArchiveOrDeleteTask",
    "ArchiveOrDeleteTaskNeopsTaskDelete",
    "ArchiveOrDeleteTaskNeopsTaskDeleteNeopsTask",
    "AsyncBaseClient",
    "AutocompleteFields",
    "BaseModel",
    "ChartType",
    "CheckResultEnum",
    "Client",
    "ClientAggregation",
    "ClientAggregationClientAggregation",
    "ClientAggregationClientAggregationResults",
    "Clients",
    "ClientsClientsElastic",
    "ClientsClientsElasticResults",
    "ClientsClientsElasticResultsInterface",
    "ClientsClientsElasticResultsInterfaceDevice",
    "ClientsClientsElasticResultsLocation",
    "ConnectionStateEnum",
    "CronExecuteTypeEnum",
    "CronExecutionType",
    "CronExecutionTypeCronjobExecutionTypes",
    "CronExecutionTypeCronjobExecutionTypesResults",
    "CronJobExecuteTypeEnum",
    "DeviceAggregation",
    "DeviceAggregationDeviceAggregation",
    "DeviceAggregationDeviceAggregationResults",
    "DeviceExecutionStateEnum",
    "DeviceGroupElastic",
    "DeviceGroupElasticGroupsElastic",
    "DeviceGroupElasticGroupsElasticResults",
    "DeviceGroupElasticGroupsElasticResultsLocation",
    "DeviceGroupUpsert",
    "DeviceGroupUpsertDeviceGroupUpsert",
    "DeviceGroupUpsertDeviceGroupUpsertDeviceGroup",
    "DeviceGroupUpsertDeviceGroupUpsertDeviceGroupDevices",
    "DeviceUpsert",
    "DeviceUpsertDeviceUpsert",
    "DeviceUpsertDeviceUpsertDevice",
    "DeviceUpsertDeviceUpsertDeviceGroups",
    "DeviceUpsertDeviceUpsertDevicePlatform",
    "Devices",
    "DevicesDevicesElastic",
    "DevicesDevicesElasticResults",
    "DevicesDevicesElasticResultsGroups",
    "DevicesDevicesElasticResultsPlatform",
    "Discovery",
    "DiscoveryExecute",
    "DiscoveryExecuteExecution",
    "EntityType",
    "ExecuteNeopsTask",
    "ExecuteNeopsTaskExecuteNeopsTask",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutions",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecution",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevice",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionDevicePlatform",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsDeviceExecutionExecution",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTask",
    "ExecuteNeopsTaskExecuteNeopsTaskExecutionsNeopsTaskProvider",
    "Execution",
    "ExecutionExecutions",
    "ExecutionExecutionsResults",
    "ExecutionExecutionsResultsDeviceExecution",
    "ExecutionExecutionsResultsDeviceExecutionDevice",
    "ExecutionExecutionsResultsDeviceExecutionDevicePlatform",
    "ExecutionExecutionsResultsExecutionResults",
    "ExecutionExecutionsResultsExecutionResultsClientexecutionresult",
    "ExecutionExecutionsResultsExecutionResultsClientexecutionresultClient",
    "ExecutionExecutionsResultsExecutionResultsDeviceexecutionresult",
    "ExecutionExecutionsResultsExecutionResultsDeviceexecutionresultDevice",
    "ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresult",
    "ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup",
    "ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresult",
    "ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresultInterface",
    "ExecutionExecutionsResultsNeopsTask",
    "ExecutionExecutionsResultsNeopsTaskProvider",
    "ExecutionExecutionsResultsProcess",
    "ExecutionResultStateEnum",
    "ExecutionStateEnum",
    "ExecutionSubscription",
    "ExecutionSubscriptionExecutionSubscription",
    "ExecutionSubscriptionExecutionSubscriptionExecution",
    "ExecutionSubscriptionExecutionSubscriptionExecutionNeopsTask",
    "ExecutionSubscriptionExecutionSubscriptionExecutionNeopsTaskProvider",
    "ExecutionSubscriptionExecutionSubscriptionExecutionProcess",
    "ExecutionTypeEnum",
    "ExecutionsDetail",
    "ExecutionsDetailExecutions",
    "ExecutionsDetailExecutionsResults",
    "ExecutionsDetailExecutionsResultsExecutionResults",
    "ExecutionsDetailExecutionsResultsExecutionResultsClientexecutionresult",
    "ExecutionsDetailExecutionsResultsExecutionResultsClientexecutionresultClient",
    "ExecutionsDetailExecutionsResultsExecutionResultsDeviceexecutionresult",
    "ExecutionsDetailExecutionsResultsExecutionResultsDeviceexecutionresultDevice",
    "ExecutionsDetailExecutionsResultsExecutionResultsDevicegroupexecutionresult",
    "ExecutionsDetailExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup",
    "ExecutionsDetailExecutionsResultsExecutionResultsInterfaceexecutionresult",
    "ExecutionsDetailExecutionsResultsExecutionResultsInterfaceexecutionresultInterface",
    "ExecutionsDetailExecutionsResultsNeopsTask",
    "ExecutionsDetailExecutionsResultsNeopsTaskProvider",
    "ExecutionsDetailExecutionsResultsProcess",
    "ExecutionsDetailExecutionsResultsUser",
    "ExecutionsElastic",
    "ExecutionsElasticExecutionsElastic",
    "ExecutionsElasticExecutionsElasticResults",
    "ExecutionsElasticExecutionsElasticResultsNeopsTask",
    "ExecutionsElasticExecutionsElasticResultsNeopsTaskProvider",
    "ExecutionsElasticExecutionsElasticResultsProcess",
    "ExecutionsElasticExecutionsElasticResultsUser",
    "ExecutionsSimple",
    "ExecutionsSimpleExecutions",
    "ExecutionsSimpleExecutionsResults",
    "ExecutionsSimpleExecutionsResultsNeopsTask",
    "ExecutionsSimpleExecutionsResultsNeopsTaskProvider",
    "ExecutionsSimpleExecutionsResultsProcess",
    "ExecutionsSimpleExecutionsResultsUser",
    "GetRole",
    "GetRoleRole",
    "GetRoleRoleResults",
    "GraphQLClientError",
    "GraphQLClientGraphQLError",
    "GraphQLClientGraphQLMultiError",
    "GraphQLClientHttpError",
    "GraphQLClientInvalidResponseError",
    "GroupAggregation",
    "GroupAggregationGroupAggregation",
    "GroupAggregationGroupAggregationResults",
    "IndexesEnum",
    "InterfaceAggregation",
    "InterfaceAggregationInterfaceAggregation",
    "InterfaceAggregationInterfaceAggregationResults",
    "InterfaceStateEnum",
    "Interfaces",
    "InterfacesInterfacesElastic",
    "InterfacesInterfacesElasticResults",
    "InterfacesInterfacesElasticResultsDevice",
    "InterfacesInterfacesElasticResultsInterface",
    "JsonForm",
    "JsonFormJsonForm",
    "JsonFormJsonFormClients",
    "JsonFormJsonFormDevices",
    "JsonFormJsonFormGroups",
    "JsonFormJsonFormInterfaces",
    "JsonFormJsonFormInterfacesDevice",
    "LocationUpsert",
    "LocationUpsertLocationUpsert",
    "LocationUpsertLocationUpsertLocation",
    "LocationUpsertLocationUpsertLocationDevices",
    "Login",
    "LoginLogin",
    "LoginLoginUser",
    "NeopsProvider",
    "NeopsProviderNeopsTaskProvider",
    "NeopsProviderNeopsTaskProviderResults",
    "NeopsTaskCreateMutation",
    "NeopsTaskCreateMutationNeopsTaskUpsert",
    "NeopsTaskCreateMutationNeopsTaskUpsertNeopsTask",
    "NeopsTaskCronJobExecuteTypeEnum",
    "NeopsTaskUnarchive",
    "NeopsTaskUnarchiveNeopsTaskUpsert",
    "NeopsTaskUnarchiveNeopsTaskUpsertNeopsTask",
    "NeopsTask_ProviderTypeEnum",
    "NeopsTask_RunOnEnum",
    "NeopsTask_RunOnStrictEnum",
    "NeopsTask_ValidityStateEnum",
    "NeopsTasks",
    "NeopsTasksNeopsTasks",
    "NeopsTasksNeopsTasksResults",
    "NeopsTasksNeopsTasksResultsPostRunTasks",
    "NeopsTasksNeopsTasksResultsPreRunTasks",
    "NeopsTasksNeopsTasksResultsProvider",
    "OutputSchemaTypeEnum",
    "Permissions",
    "PermissionsPermissions",
    "PermissionsPermissionsResults",
    "Platforms",
    "PlatformsPlatforms",
    "PlatformsPlatformsResults",
    "ProcessOverview",
    "ProcessOverviewProcessExecutions",
    "ProcessOverviewProcessExecutionsResults",
    "ProcessOverviewProcessExecutionsResultsExecutions",
    "ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecution",
    "ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevice",
    "ProcessOverviewProcessExecutionsResultsExecutionsDeviceExecutionDevicePlatform",
    "ProcessOverviewProcessExecutionsResultsExecutionsExecutionResults",
    "ProcessOverviewProcessExecutionsResultsExecutionsNeopsTask",
    "ProcessOverviewProcessExecutionsResultsExecutionsNeopsTaskProvider",
    "ProviderSchemaEnum",
    "ProviderTypeEnum",
    "Providers",
    "ProvidersNeopsTaskProvider",
    "ProvidersNeopsTaskProviderResults",
    "RefreshToken",
    "RefreshTokenRefreshToken",
    "RegexTypeEnum",
    "Reports",
    "ReportsExecute",
    "ReportsExecuteReportsExecute",
    "ReportsExecuteReportsExecuteReportExecution",
    "ReportsReports",
    "ReportsReportsResults",
    "ReportsReportsResultsScope",
    "RoleDeviceGroup",
    "RoleDeviceGroupRoleDeviceGroup",
    "RoleDeviceGroupRoleDeviceGroupResults",
    "RoleDeviceGroupRoleDeviceGroupResultsDeviceGroup",
    "RoleDeviceGroupRoleDeviceGroupResultsRole",
    "RoleDeviceGroupUpsert",
    "RoleDeviceGroupUpsertRoleDeviceGroupUpsert",
    "RoleDeviceGroupUpsertRoleDeviceGroupUpsertRoleDeviceGroup",
    "RoleNeopsTask",
    "RoleNeopsTaskRoleNeopsTask",
    "RoleNeopsTaskRoleNeopsTaskResults",
    "RoleNeopsTaskRoleNeopsTaskResultsNeopsTask",
    "RoleNeopsTaskRoleNeopsTaskResultsRole",
    "RoleNeopsTaskUpsert",
    "RoleNeopsTaskUpsertRoleNeopsTaskUpsert",
    "RoleNeopsTaskUpsertRoleNeopsTaskUpsertRoleNeopsTask",
    "RolePermissionElement",
    "RolePermissionElementRolePermissionElement",
    "RolePermissionElementRolePermissionElementResults",
    "RolePermissionElementRolePermissionElementResultsPermissionElement",
    "RolePermissionElementUpsert",
    "RolePermissionElementUpsertRolePermissionElementUpsert",
    "RolePermissionElementUpsertRolePermissionElementUpsertRolePermissionElement",
    "RolePermissionUpsert",
    "RolePermissionUpsertRolePermissionUpsert",
    "RolePermissionUpsertRolePermissionUpsertRolePermission",
    "RolePermissions",
    "RolePermissionsRolePermission",
    "RolePermissionsRolePermissionResults",
    "RolePermissionsRolePermissionResultsDeviceGroupPermissionsAll",
    "RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllDeviceGroup",
    "RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllRole",
    "RolePermissionsRolePermissionResultsNeopsTaskPermissionsAll",
    "RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllNeopsTask",
    "RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllRole",
    "RolePermissionsRolePermissionResultsPermissionElementPermissionsAll",
    "RolePermissionsRolePermissionResultsPermissionElementPermissionsAllPermissionElement",
    "RolePermissionsRolePermissionResultsPermissionElementPermissionsAllRole",
    "RolePermissionsRolePermissionResultsScopePermissionsAll",
    "RolePermissionsRolePermissionResultsScopePermissionsAllRole",
    "RolePermissionsRolePermissionResultsScopePermissionsAllScope",
    "RolePermissionsRolePermissionResultsUsers",
    "RoleScopeUpsert",
    "RoleScopeUpsertRoleScopeUpsert",
    "RoleScopeUpsertRoleScopeUpsertRoleScope",
    "RoleUser",
    "RoleUserRole",
    "RoleUserRoleResults",
    "Rollback",
    "RollbackDeviceRollback",
    "RollbackDeviceRollbackExecution",
    "RunOnEnum",
    "SavedSearchCreate",
    "SavedSearchCreateSavedSearchCreate",
    "SavedSearchCreateSavedSearchCreateSavedSearch",
    "SavedSearchDelete",
    "SavedSearchDeleteSavedSearchDelete",
    "SavedSearchDeleteSavedSearchDeleteSavedSearch",
    "SavedSearches",
    "SavedSearchesSavedSearches",
    "SavedSearchesSavedSearchesResults",
    "ScopeDelete",
    "ScopeDeleteScopeDelete",
    "ScopeDeleteScopeDeleteScope",
    "Scopes",
    "ScopesScopes",
    "ScopesScopesResults",
    "ScopesScopesResultsTasks",
    "ScopesUpsert",
    "ScopesUpsertScopesUpsert",
    "ScopesUpsertScopesUpsertScope",
    "SingleDiscovery",
    "SingleDiscoveryDiscovery",
    "SingleDiscoveryDiscoveryExecution",
    "Topology",
    "TopologyTopology",
    "TopologyTopologyLinks",
    "TopologyTopologyLinksProperties",
    "TopologyTopologyLinksPropertiesSourceInterface",
    "TopologyTopologyLinksPropertiesTargetInterface",
    "TopologyTopologyNodes",
    "TopologyTopologyNodesProperties",
    "TopologyTopologyNodesPropertiesDevice",
    "Upload",
]



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class Login(BaseModel):
    login: Optional["LoginLogin"]


class LoginLogin(BaseModel):
    access_token: Optional[str] = Field(alias="accessToken")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    roles: Optional[List[Optional[str]]]
    user: Optional["LoginLoginUser"]


class LoginLoginUser(BaseModel):
    id: str
    email: Optional[str]
    username: Optional[str]


Login.model_rebuild()
LoginLogin.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class SavedSearches(BaseModel):
    saved_searches: Optional["SavedSearchesSavedSearches"] = Field(
        alias="savedSearches"
    )


class SavedSearchesSavedSearches(BaseModel):
    results: Optional[List[Optional["SavedSearchesSavedSearchesResults"]]]


class SavedSearchesSavedSearchesResults(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    search: Optional[str]


SavedSearches.model_rebuild()
SavedSearchesSavedSearches.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    DeviceExecutionStateEnum,
    ExecutionResultStateEnum,
    ExecutionStateEnum,
    ExecutionTypeEnum,
    ProviderTypeEnum,
    RunOnEnum,
)


class Execution(BaseModel):
    executions: Optional["ExecutionExecutions"]


class ExecutionExecutions(BaseModel):
    results: Optional[List[Optional["ExecutionExecutionsResults"]]]


class ExecutionExecutionsResults(BaseModel):
    id: str
    task_id: Optional[str] = Field(alias="taskId")
    name: Optional[str]
    execution_type: Optional[ExecutionTypeEnum] = Field(alias="executionType")
    created_at: Optional[Any] = Field(alias="createdAt")
    updated_at: Optional[Any] = Field(alias="updatedAt")
    log: Optional[str]
    do: Optional[str]
    done: Optional[str]
    process: Optional["ExecutionExecutionsResultsProcess"]
    neops_task: Optional["ExecutionExecutionsResultsNeopsTask"] = Field(
        alias="neopsTask"
    )
    state: Optional[ExecutionStateEnum]
    device_execution: Optional[
        List[Optional["ExecutionExecutionsResultsDeviceExecution"]]
    ] = Field(alias="deviceExecution")
    execution_results: Optional[
        List[Optional["ExecutionExecutionsResultsExecutionResults"]]
    ] = Field(alias="executionResults")


class ExecutionExecutionsResultsProcess(BaseModel):
    name: Optional[str]
    id: str


class ExecutionExecutionsResultsNeopsTask(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    provider: Optional["ExecutionExecutionsResultsNeopsTaskProvider"]


class ExecutionExecutionsResultsNeopsTaskProvider(BaseModel):
    provider_type: Optional[ProviderTypeEnum] = Field(alias="providerType")


class ExecutionExecutionsResultsDeviceExecution(BaseModel):
    id: str
    device: Optional["ExecutionExecutionsResultsDeviceExecutionDevice"]
    run_on: Optional[RunOnEnum] = Field(alias="runOn")
    execute_on: Optional[List[Optional[int]]] = Field(alias="executeOn")
    state: Optional[DeviceExecutionStateEnum]
    result: Optional[Any]
    do: Optional[str]
    exception: Optional[str]
    done: Optional[str]
    changed: Optional[bool]
    log: Optional[str]


class ExecutionExecutionsResultsDeviceExecutionDevice(BaseModel):
    id: str
    hostname: Optional[str]
    platform: Optional["ExecutionExecutionsResultsDeviceExecutionDevicePlatform"]


class ExecutionExecutionsResultsDeviceExecutionDevicePlatform(BaseModel):
    id: str
    name: Optional[str]


class ExecutionExecutionsResultsExecutionResults(BaseModel):
    devicegroupexecutionresult: Optional[
        "ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresult"
    ]
    deviceexecutionresult: Optional[
        "ExecutionExecutionsResultsExecutionResultsDeviceexecutionresult"
    ]
    clientexecutionresult: Optional[
        "ExecutionExecutionsResultsExecutionResultsClientexecutionresult"
    ]
    interfaceexecutionresult: Optional[
        "ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresult"
    ]


class ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresult(BaseModel):
    group: Optional[
        "ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup"
    ]
    granularity: Optional[int]
    message: Optional[str]
    state: Optional[ExecutionResultStateEnum]


class ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresultGroup(
    BaseModel
):
    name: Optional[str]


class ExecutionExecutionsResultsExecutionResultsDeviceexecutionresult(BaseModel):
    device: Optional[
        "ExecutionExecutionsResultsExecutionResultsDeviceexecutionresultDevice"
    ]
    granularity: Optional[int]
    message: Optional[str]
    state: Optional[ExecutionResultStateEnum]


class ExecutionExecutionsResultsExecutionResultsDeviceexecutionresultDevice(BaseModel):
    hostname: Optional[str]


class ExecutionExecutionsResultsExecutionResultsClientexecutionresult(BaseModel):
    client: Optional[
        "ExecutionExecutionsResultsExecutionResultsClientexecutionresultClient"
    ]
    granularity: Optional[int]
    message: Optional[str]
    state: Optional[ExecutionResultStateEnum]


class ExecutionExecutionsResultsExecutionResultsClientexecutionresultClient(BaseModel):
    macaddress: Optional[str]


class ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresult(BaseModel):
    interface: Optional[
        "ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresultInterface"
    ]
    granularity: Optional[int]
    message: Optional[str]
    state: Optional[ExecutionResultStateEnum]


class ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresultInterface(
    BaseModel
):
    name: Optional[str]


Execution.model_rebuild()
ExecutionExecutions.model_rebuild()
ExecutionExecutionsResults.model_rebuild()
ExecutionExecutionsResultsNeopsTask.model_rebuild()
ExecutionExecutionsResultsDeviceExecution.model_rebuild()
ExecutionExecutionsResultsDeviceExecutionDevice.model_rebuild()
ExecutionExecutionsResultsExecutionResults.model_rebuild()
ExecutionExecutionsResultsExecutionResultsDevicegroupexecutionresult.model_rebuild()
ExecutionExecutionsResultsExecutionResultsDeviceexecutionresult.model_rebuild()
ExecutionExecutionsResultsExecutionResultsClientexecutionresult.model_rebuild()
ExecutionExecutionsResultsExecutionResultsInterfaceexecutionresult.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SavedSearchCreate(BaseModel):
    saved_search_create: Optional["SavedSearchCreateSavedSearchCreate"] = Field(
        alias="savedSearchCreate"
    )


class SavedSearchCreateSavedSearchCreate(BaseModel):
    saved_search: Optional["SavedSearchCreateSavedSearchCreateSavedSearch"] = Field(
        alias="savedSearch"
    )


class SavedSearchCreateSavedSearchCreateSavedSearch(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    search: Optional[str]


SavedSearchCreate.model_rebuild()
SavedSearchCreateSavedSearchCreate.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class RefreshToken(BaseModel):
    refresh_token: Optional["RefreshTokenRefreshToken"] = Field(alias="refreshToken")


class RefreshTokenRefreshToken(BaseModel):
    access_token: Optional[str] = Field(alias="accessToken")
    refresh_token: Optional[str] = Field(alias="refreshToken")


RefreshToken.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class ClientAggregation(BaseModel):
    client_aggregation: Optional["ClientAggregationClientAggregation"] = Field(
        alias="clientAggregation"
    )


class ClientAggregationClientAggregation(BaseModel):
    results: Optional[List[Optional["ClientAggregationClientAggregationResults"]]]
    count_aggregated_elements: Optional[int] = Field(alias="countAggregatedElements")
    count: Optional[int]


class ClientAggregationClientAggregationResults(BaseModel):
    value: Optional[str]
    count: Optional[int]


ClientAggregation.model_rebuild()
ClientAggregationClientAggregation.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GroupAggregation(BaseModel):
    group_aggregation: Optional["GroupAggregationGroupAggregation"] = Field(
        alias="groupAggregation"
    )


class GroupAggregationGroupAggregation(BaseModel):
    results: Optional[List[Optional["GroupAggregationGroupAggregationResults"]]]
    count_aggregated_elements: Optional[int] = Field(alias="countAggregatedElements")
    count: Optional[int]


class GroupAggregationGroupAggregationResults(BaseModel):
    value: Optional[str]
    count: Optional[int]


GroupAggregation.model_rebuild()
GroupAggregationGroupAggregation.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class Clients(BaseModel):
    clients_elastic: Optional["ClientsClientsElastic"] = Field(alias="clientsElastic")


class ClientsClientsElastic(BaseModel):
    total_count: Optional[int] = Field(alias="totalCount")
    results: Optional[List[Optional["ClientsClientsElasticResults"]]]


class ClientsClientsElasticResults(BaseModel):
    id: str
    created_at: Optional[Any] = Field(alias="createdAt")
    updated_at: Optional[Any] = Field(alias="updatedAt")
    fromimport: Optional[bool]
    lastdiscovered: Optional[Any]
    macaddress: Optional[str]
    facts: Optional[Any]
    interface: Optional["ClientsClientsElasticResultsInterface"]
    location: Optional["ClientsClientsElasticResultsLocation"]
    checks: Optional[Any]


class ClientsClientsElasticResultsInterface(BaseModel):
    id: str
    name: Optional[str]
    device: Optional["ClientsClientsElasticResultsInterfaceDevice"]


class ClientsClientsElasticResultsInterfaceDevice(BaseModel):
    id: str
    hostname: Optional[str]
    ip: Optional[str]


class ClientsClientsElasticResultsLocation(BaseModel):
    id: str
    name: Optional[str]
    address: Optional[str]
    city: Optional[str]
    country: Optional[str]
    lat: Optional[float]
    lon: Optional[float]


Clients.model_rebuild()
ClientsClientsElastic.model_rebuild()
ClientsClientsElasticResults.model_rebuild()
ClientsClientsElasticResultsInterface.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ArchiveOrDeleteTask(BaseModel):
    neops_task_delete: Optional["ArchiveOrDeleteTaskNeopsTaskDelete"] = Field(
        alias="neopsTaskDelete"
    )


class ArchiveOrDeleteTaskNeopsTaskDelete(BaseModel):
    neops_task: Optional["ArchiveOrDeleteTaskNeopsTaskDeleteNeopsTask"] = Field(
        alias="neopsTask"
    )


class ArchiveOrDeleteTaskNeopsTaskDeleteNeopsTask(BaseModel):
    id: str


ArchiveOrDeleteTask.model_rebuild()
ArchiveOrDeleteTaskNeopsTaskDelete.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RolePermissions(BaseModel):
    role_permission: Optional["RolePermissionsRolePermission"] = Field(
        alias="rolePermission"
    )


class RolePermissionsRolePermission(BaseModel):
    results: Optional[List[Optional["RolePermissionsRolePermissionResults"]]]


class RolePermissionsRolePermissionResults(BaseModel):
    id: str
    name: Optional[str]
    default_permission: Optional[int] = Field(alias="defaultPermission")
    default_permission_flags: Optional[List[Optional[str]]] = Field(
        alias="defaultPermissionFlags"
    )
    permission_all_flags: Optional[List[Optional[str]]] = Field(
        alias="permissionAllFlags"
    )
    permission_element_permissions_all: Optional[
        List[
            Optional[
                "RolePermissionsRolePermissionResultsPermissionElementPermissionsAll"
            ]
        ]
    ] = Field(alias="permissionElementPermissionsAll")
    device_group_permissions_all: Optional[
        List[Optional["RolePermissionsRolePermissionResultsDeviceGroupPermissionsAll"]]
    ] = Field(alias="deviceGroupPermissionsAll")
    neops_task_permissions_all: Optional[
        List[Optional["RolePermissionsRolePermissionResultsNeopsTaskPermissionsAll"]]
    ] = Field(alias="neopsTaskPermissionsAll")
    scope_permissions_all: Optional[
        List[Optional["RolePermissionsRolePermissionResultsScopePermissionsAll"]]
    ] = Field(alias="scopePermissionsAll")
    users: Optional[List[Optional["RolePermissionsRolePermissionResultsUsers"]]]


class RolePermissionsRolePermissionResultsPermissionElementPermissionsAll(BaseModel):
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")
    permission_all_flags: Optional[List[Optional[str]]] = Field(
        alias="permissionAllFlags"
    )
    permission_element: Optional[
        "RolePermissionsRolePermissionResultsPermissionElementPermissionsAllPermissionElement"
    ] = Field(alias="permissionElement")
    role: Optional[
        "RolePermissionsRolePermissionResultsPermissionElementPermissionsAllRole"
    ]


class RolePermissionsRolePermissionResultsPermissionElementPermissionsAllPermissionElement(
    BaseModel
):
    id: str
    name: Optional[str]
    description: Optional[str]


class RolePermissionsRolePermissionResultsPermissionElementPermissionsAllRole(
    BaseModel
):
    id: str
    name: Optional[str]


class RolePermissionsRolePermissionResultsDeviceGroupPermissionsAll(BaseModel):
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")
    permission_all_flags: Optional[List[Optional[str]]] = Field(
        alias="permissionAllFlags"
    )
    role: Optional["RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllRole"]
    device_group: Optional[
        "RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllDeviceGroup"
    ] = Field(alias="deviceGroup")


class RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllRole(BaseModel):
    id: str
    name: Optional[str]


class RolePermissionsRolePermissionResultsDeviceGroupPermissionsAllDeviceGroup(
    BaseModel
):
    id: str
    name: Optional[str]
    description: Optional[str]


class RolePermissionsRolePermissionResultsNeopsTaskPermissionsAll(BaseModel):
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")
    permission_all_flags: Optional[List[Optional[str]]] = Field(
        alias="permissionAllFlags"
    )
    role: Optional["RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllRole"]
    neops_task: Optional[
        "RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllNeopsTask"
    ] = Field(alias="neopsTask")


class RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllRole(BaseModel):
    id: str
    name: Optional[str]


class RolePermissionsRolePermissionResultsNeopsTaskPermissionsAllNeopsTask(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]


class RolePermissionsRolePermissionResultsScopePermissionsAll(BaseModel):
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")
    permission_all_flags: Optional[List[Optional[str]]] = Field(
        alias="permissionAllFlags"
    )
    role: Optional["RolePermissionsRolePermissionResultsScopePermissionsAllRole"]
    scope: Optional["RolePermissionsRolePermissionResultsScopePermissionsAllScope"]


class RolePermissionsRolePermissionResultsScopePermissionsAllRole(BaseModel):
    id: str
    name: Optional[str]


class RolePermissionsRolePermissionResultsScopePermissionsAllScope(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]


class RolePermissionsRolePermissionResultsUsers(BaseModel):
    id: str
    username: Optional[str]
    last_name: Optional[str] = Field(alias="lastName")
    first_name: Optional[str] = Field(alias="firstName")
    email: Optional[str]


RolePermissions.model_rebuild()
RolePermissionsRolePermission.model_rebuild()
RolePermissionsRolePermissionResults.model_rebuild()
RolePermissionsRolePermissionResultsPermissionElementPermissionsAll.model_rebuild()
RolePermissionsRolePermissionResultsDeviceGroupPermissionsAll.model_rebuild()
RolePermissionsRolePermissionResultsNeopsTaskPermissionsAll.model_rebuild()
RolePermissionsRolePermissionResultsScopePermissionsAll.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ScopesUpsert(BaseModel):
    scopes_upsert: Optional["ScopesUpsertScopesUpsert"] = Field(alias="scopesUpsert")


class ScopesUpsertScopesUpsert(BaseModel):
    scope: Optional["ScopesUpsertScopesUpsertScope"]


class ScopesUpsertScopesUpsertScope(BaseModel):
    id: str
    name: Optional[str]


ScopesUpsert.model_rebuild()
ScopesUpsertScopesUpsert.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RoleScopeUpsert(BaseModel):
    role_scope_upsert: Optional["RoleScopeUpsertRoleScopeUpsert"] = Field(
        alias="roleScopeUpsert"
    )


class RoleScopeUpsertRoleScopeUpsert(BaseModel):
    role_scope: Optional["RoleScopeUpsertRoleScopeUpsertRoleScope"] = Field(
        alias="roleScope"
    )


class RoleScopeUpsertRoleScopeUpsertRoleScope(BaseModel):
    id: str
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")


RoleScopeUpsert.model_rebuild()
RoleScopeUpsertRoleScopeUpsert.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import RunOnEnum


class NeopsTasks(BaseModel):
    neops_tasks: Optional["NeopsTasksNeopsTasks"] = Field(alias="neopsTasks")


class NeopsTasksNeopsTasks(BaseModel):
    results: Optional[List[Optional["NeopsTasksNeopsTasksResults"]]]


class NeopsTasksNeopsTasksResults(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    uniquetaskname: Optional[str]
    provider_identifier: Optional[str] = Field(alias="providerIdentifier")
    run_on: Optional[RunOnEnum] = Field(alias="runOn")
    run_on_strict: Optional[bool] = Field(alias="runOnStrict")
    is_check: Optional[bool] = Field(alias="isCheck")
    is_task: Optional[bool] = Field(alias="isTask")
    provider: Optional["NeopsTasksNeopsTasksResultsProvider"]
    task_kwargs: Optional[Any] = Field(alias="taskKwargs")
    task_run_input_schema: Optional[Any] = Field(alias="taskRunInputSchema")
    task_run_filter: Optional[str] = Field(alias="taskRunFilter")
    pre_run_tasks: Optional[
        List[Optional["NeopsTasksNeopsTasksResultsPreRunTasks"]]
    ] = Field(alias="preRunTasks")
    post_run_tasks: Optional[
        List[Optional["NeopsTasksNeopsTasksResultsPostRunTasks"]]
    ] = Field(alias="postRunTasks")
    created_at: Optional[Any] = Field(alias="createdAt")
    updated_at: Optional[Any] = Field(alias="updatedAt")
    permission: Optional[int]
    is_valid: Optional[bool] = Field(alias="isValid")
    is_valid_recursive: Optional[bool] = Field(alias="isValidRecursive")
    validity_information: Optional[str] = Field(alias="ValidityInformation")


class NeopsTasksNeopsTasksResultsProvider(BaseModel):
    name: Optional[str]
    json_schema: Optional[Any] = Field(alias="jsonSchema")
    short_description: Optional[str] = Field(alias="shortDescription")
    deprecated: Optional[bool]
    description: Optional[str]


class NeopsTasksNeopsTasksResultsPreRunTasks(BaseModel):
    id: str
    name: Optional[str]


class NeopsTasksNeopsTasksResultsPostRunTasks(BaseModel):
    id: str
    name: Optional[str]


NeopsTasks.model_rebuild()
NeopsTasksNeopsTasks.model_rebuild()
NeopsTasksNeopsTasksResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import InterfaceStateEnum


class Interfaces(BaseModel):
    interfaces_elastic: Optional["InterfacesInterfacesElastic"] = Field(
        alias="interfacesElastic"
    )


class InterfacesInterfacesElastic(BaseModel):
    total_count: Optional[int] = Field(alias="totalCount")
    results: Optional[List[Optional["InterfacesInterfacesElasticResults"]]]


class InterfacesInterfacesElasticResults(BaseModel):
    id: str
    created_at: Optional[Any] = Field(alias="createdAt")
    updated_at: Optional[Any] = Field(alias="updatedAt")
    name: Optional[str]
    description: Optional[str]
    state: Optional[InterfaceStateEnum]
    facts: Optional[Any]
    current_configuration: Optional[str] = Field(alias="currentConfiguration")
    interface: Optional["InterfacesInterfacesElasticResultsInterface"]
    device: Optional["InterfacesInterfacesElasticResultsDevice"]
    checks: Optional[Any]
    client_count: Optional[int] = Field(alias="clientCount")


class InterfacesInterfacesElasticResultsInterface(BaseModel):
    id: str


class InterfacesInterfacesElasticResultsDevice(BaseModel):
    id: str
    hostname: Optional[str]
    ip: Optional[str]


Interfaces.model_rebuild()
InterfacesInterfacesElastic.model_rebuild()
InterfacesInterfacesElasticResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ExecutionStateEnum


class AbortExecution(BaseModel):
    abort_execution: Optional["AbortExecutionAbortExecution"] = Field(
        alias="abortExecution"
    )


class AbortExecutionAbortExecution(BaseModel):
    executions: Optional[List[Optional["AbortExecutionAbortExecutionExecutions"]]]


class AbortExecutionAbortExecutionExecutions(BaseModel):
    id: str
    name: Optional[str]
    state: Optional[ExecutionStateEnum]
    neops_task: Optional["AbortExecutionAbortExecutionExecutionsNeopsTask"] = Field(
        alias="neopsTask"
    )


class AbortExecutionAbortExecutionExecutionsNeopsTask(BaseModel):
    id: str
    name: Optional[str]


AbortExecution.model_rebuild()
AbortExecutionAbortExecution.model_rebuild()
AbortExecutionAbortExecutionExecutions.model_rebuild()



# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SavedSearchDelete(BaseModel):
    saved_search_delete: Optional["SavedSearchDeleteSavedSearchDelete"] = Field(
        alias="savedSearchDelete"
    )


class SavedSearchDeleteSavedSearchDelete(BaseModel):
    saved_search: Optional["SavedSearchDeleteSavedSearchDeleteSavedSearch"] = Field(
        alias="savedSearch"
    )


class SavedSearchDeleteSavedSearchDeleteSavedSearch(BaseModel):
    id: str


SavedSearchDelete.model_rebuild()
SavedSearchDeleteSavedSearchDelete.model_rebuild()
